@@ -112,7 +112,7 @@ Rcpp::NumericVector ExpMean(const arma::mat& phi, const arma::vec& iota,
 // [[Rcpp::depends(RcppArmadillo)]]
 // [[Rcpp::export(.IndirectCentrals)]]
 arma::mat IndirectCentrals(const arma::mat& phi, const arma::vec& delta_t) {
-  arma::mat output(phi.n_rows, delta_t.n_elem, arma::fill::none);
+  arma::mat output(phi.n_rows, delta_t.n_elem, arma::fill::zeros);
   arma::mat total(phi.n_rows, phi.n_cols, arma::fill::none);
   arma::mat direct(phi.n_rows, phi.n_cols, arma::fill::none);
   arma::mat d = arma::eye(phi.n_rows, phi.n_cols);
